@@ -1,4 +1,4 @@
-__version__ = "1.1.0"
+__version__ = "1.2.1"
 __version_info__ = tuple(
     map(
         lambda val: int(val) if val.isnumeric() else val,
@@ -6,24 +6,22 @@ __version_info__ = tuple(
     )
 )
 
-from . import exc
-from ._datastructures import (
-    ContextGetter,
-    ImmutableAsyncProvider,
-    ImmutableSyncProvider,
-    StateWrapper,
-)
+from . import ensure_context, exc
+from ._datastructures import ImmutableAsyncProvider, ImmutableSyncProvider, StateWrapper
 from .context import AsyncContext, SyncContext
-from . import ensure_context
-from .factory import context_factory
+from .generic import AsyncGenericFactory, GenericFactory
+from .getters import ArgType, context_factory, get_context
 
 __all__ = [
     "AsyncContext",
     "SyncContext",
     "context_factory",
+    "get_context",
+    "GenericFactory",
+    "AsyncGenericFactory",
     "exc",
     "ensure_context",
-    "ContextGetter",
+    "ArgType",
     "ImmutableSyncProvider",
     "ImmutableAsyncProvider",
     "StateWrapper",
